translate.lang.fa

Package translate :: Package lang :: Module fa |
[hide private]
[frames] | no frames]

# Module fa

source code

This module represents Persian language.

For more information, see http://en.wikipedia.org/wiki/Persian_language

Classes | [hide private]
| fa This class represents Persian.

Functions | [hide private]
guillemets(text) | source code

Variables | [hide private]
| __package__ = ``'``translate.lang``'``

Imports: common, re